@@ -5,6 +5,7 @@ import os
 from .prototype import WikiSectionDict
 from typing import Union
 
+
 class Bot:
     '''(https://www.mediawiki.org/wiki/API:Main_page/zh)[Mediawiki文档]
     现阶段要求sitename, api，index，username，password五个参数'''
@@ -22,8 +23,11 @@ class Bot:
         self.headers = {
             'User-Agent': 'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/67.0.3396.62 Safari/537.36'}
 
+    async def __aexit__(self):
+        await self.client.aclose()
+
     async def fetch_token(self, type:str)->str:
-        '''fetch_token(type=STRING)
+        '''fetch_token(type:str)
         根据不同的type类型返回对应的token'''
         PARAMS = {
             'action': "query",
@@ -51,8 +55,6 @@ class Bot:
         if login['login']['result'] == "Success":
             logger.info(f'Welcome to {self.sitename}, {login["login"]["lgusername"]}!')
 
-    async def close(self):
-        await self.client.aclose()
 
     async def get_data(self, title:str):
         PARAMS = {
@@ -104,7 +106,7 @@ class Bot:
         PARAMS["summary"] += " //Edit by Bot."
         act = await self.client.post(url=self.api, data=PARAMS, headers=self.headers)
         act = act.json()
-        if act['edit']['result'] == "Success":
+        if ('edit'['result'] in act) & (act['edit'][result]== "Success"):
             logger.info(f'Edit [[{PARAMS["title"]}]] successfully.')
         else:
             logger.debug(act)
@@ -127,17 +129,20 @@ class Bot:
             "format": "json",
             "token": self.fetch_token(type="csrf"),
             "ignorewarnings": True,
-            "watchlist" :"nochange"
+            "watchlist": "nochange",
+            "async": True
         }
         for key, value in kwargs.items():
             key = str(key)
             value = str(value)
             PARAMS[key] = value
         FILE = {'file': (local_name, open(local_path, 'rb'), 'multipart/form-data')}
-        act = await self.client.post(url=self.api, data=PARAMS,headers=self.headers, files=FILE)
+        act = await self.client.post(url=self.api, data=PARAMS, headers=self.headers, files=FILE)
         act = act.json()
-        # logger.info(f'Upload {local_name}=>[[File:{web_name}]] successfully.')
-        print(act)
+        if act["upload"]["result"] == "Success":
+            logger.info(f'Upload {local_name}=>[[File:{web_name}]] successfully.')
+        else:
+            logger.debug(act)
 
     async def purge(self,title:str,**kwargs):
         '''刷新页面'''
@@ -168,7 +173,6 @@ class Bot:
         act = await self.client.post(url=self.api, data=PARAMS, headers=self.headers)
         return act.json()
 
-
     async def get_sections(self, title:str)->WikiSectionDict:
         result = await self.parse(title=title, prop='sections')
         result = result['parse']['sections']
@@ -208,5 +212,62 @@ class Bot:
         act = await self.client.post(url=self.api, data=PARAMS, headers=self.headers).json()
         logger.info(f"Reply the flow {title} successfully.")
 
-    async def rc(self,namespace):
-        ...
\ No newline at end of file
+    def rc(self,namespace):
+        ...
+    async def search(self, txt:str, namespace:str="0", sroffset:str="0", **kwargs):
+        PARAMS = {
+            "action":"query",
+            "list":"search",
+            "srsearch":txt,
+            "srlimit":"max",
+            "utf8":"",
+            "srnamespace":namespace,
+            "srwhat":"text",
+            "sroffset":sroffset,
+            "format": "json",
+        }
+        for key, value in kwargs.items():
+            key = str(key)
+            value = str(value)
+            PARAMS[key] = value
+        act = await self.client.post(url=self.api, data=PARAMS, headers=self.headers)
+        act = act.json()
+        rl = []
+        if act["query"]["search"] != False: 
+            print(len(act["query"]["search"]),sroffset)
+            for i in act["query"]["search"]:
+                rl.append(i["title"])    
+        if "continue" in act:
+            temp = await self.search(txt=txt,namespace=namespace,sroffset=(int(sroffset)+1),**kwargs)
+            for i in temp:rl.append(i)
+        return rl
+
+    async def ask(self,query:str,api_version:int=2):
+        PARAMS = {
+            "action":"ask",
+            "query":query,
+            "api_version":api_version,
+            "format": "json",
+        }
+        act = await self.client.post(url=self.api, data=PARAMS, headers=self.headers)
+        act = act.json()
+        return act["query"]
+
+    async def protect(self,title,protections,expiry:str="infinite",reason:str="",**kwargs):
+        PARAMS = {
+            "action": "protect",
+            "format": "json",
+            "title": title,
+            "protections":protections,
+            "expiry":expiry,
+            "reason":reason
+        }
+        for key, value in kwargs.items():
+            key = str(key)
+            value = str(value)
+            PARAMS[key] = value
+        PARAMS["token"] = await self.fetch_token(type="csrf")
+        PARAMS["reason"] += " //Protect by Bot."
+        act = await self.client.post(url=self.api, data=PARAMS, headers=self.headers)
+        act = act.json()
+        return act["protect"]
\ No newline at end of file
